@@ -8,7 +8,7 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:MAROS';
-our $VERSION = '1.41';
+our $VERSION = '1.42';
 
 use MooseX::App::Meta::Role::Attribute::Option;
 use MooseX::App::Exporter qw(app_usage app_description app_base app_fuzzy app_strict app_prefer_commandline app_permute option parameter);
@@ -297,7 +297,7 @@ This is equivalent to
       cmd_type      => 'option',        # Set attribute type
   );
 
-Single letter options are treated as flags and may be combined with eachother.
+Single letter options are treated as flags and may be combined with each other.
 However such options must have a Boolean type constraint.
 
  option 'verbose' => (
@@ -443,7 +443,7 @@ classes will be disabled entirely.
 
  app_exclude 'MyApp::Commands::Roles','MyApp::Commands::Utils';
 
-A sub namespace included via app_namespace (or the default behaviour) can
+A sub namespace included via L<app_namespace> (or the default behaviour) can
 be excluded using app_exclude.
 
 =head2 app_command_name
@@ -465,7 +465,7 @@ command class will be skipped and not loaded.
     undo    => 'MyApp::Commands::UndoSomething';
 
 This keyword can be used to register additional commands. Especially
-useful in conjunction with app_namespace and disabled autoloading.
+useful in conjunction with L<app_namespace> and disabled autoloading.
 
 =head2 app_description
 
@@ -492,7 +492,7 @@ will be autogenerated. (see command_usage to set usage per command)
 Allows one to specify multiple values with one key. So instead of writing
 C<--list element1 --list element2 --list element3> one might write
 C<--list element1 element2 element3> for ArrayRef elements. HashRef elements
-may be expressed as <--hash key=value key2=value2>.
+may be expressed as C<--hash key=value key2=value2>.
 
 =head1 GLOBAL ATTRIBUTES
 
@@ -519,7 +519,7 @@ Options and parameters accept extra attributes for customisation:
 
 =item * cmd_aliases - Additional option/parameter name aliases
 
-=item * cmd_split - Split values into ArrayRefs on this token
+=item * cmd_split - Split values into ArrayRefs on this token or RegEx
 
 =item * cmd_position - Specify option/parameter order in help
 
@@ -544,9 +544,9 @@ and should be provided if possible:
 
 =item * Package names
 
-=item * L<required> options for Moose attributes
+=item * L<required|Moose/"required-=E<gt>-(1|0)"> options for Moose attributes
 
-=item * L<documentation> options for Moose attributes
+=item * L<documentation|Moose/"documentation =E<gt> $string"> options for Moose attributes
 
 =item * Moose type constraints (Bool, ArrayRef, HashRef, Int, Num, and Enum)
 
@@ -556,7 +556,7 @@ command_short_description, command_long_description and command_usage
 =item * POD (NAME, ABSTRACT, DESCRIPTION, USAGE, SYNOPSIS, OVERVIEW,
 COPYRIGHT, LICENSE, COPYRIGHT AND LICENSE, AUTHOR and AUTHORS sections)
 
-=item * Dzil ABSTRACT tag if no POD is available yet
+=item * L<Dist::Zilla> ABSTRACT tag if no POD is available yet
 
 =back
 
@@ -619,6 +619,12 @@ Adds dependent options.
 Refer to L<Writing MooseX-App Plugins|MooseX::App::WritingPlugins>
 for documentation on how to create your own plugins.
 
+=head1 DEVELOPMENT
+
+Make sure to invoke your script with APP_DEVELOPER=1 ser during development. This
+will come with a starup penalty but perform additional checks for detecting wrong
+attribute/type constraint combinations, name clashes, ...
+
 =head1 CAVEATS & KNOWN BUGS
 
 Startup time may be an issue - escpecially if you load many plugins. If you do
@@ -649,7 +655,7 @@ MooseX::App command line application.
 
 For alternatives you can check out
 
-L<MooseX::App::Cmd>, L<MooseX::Getopt>, L<MooX::Options>, L<MooX::Cmd>and L<App::Cmd>
+L<MooseX::App::Cmd>, L<MooseX::Getopt>, L<MooX::Options>, L<MooX::Cmd> and L<App::Cmd>
 
 =head1 SUPPORT
 
@@ -674,7 +680,7 @@ In no particular order: Andrew Jones, George Hartzell, Steve Nolte,
 Michael G, Thomas Klausner, Yanick Champoux, Edward Baudrez, David Golden,
 J.R. Mash, Thilo Fester, Gregor Herrmann, Sergey Romanov, Sawyer X, Roman F.,
 Hunter McMillen, Maik Hentsche, Alexander Stoddard, Marc Logghe, Tina Müller,
-Lisa Hare, Jose Luis Martinez
+Lisa Hare, Jose Luis Martinez, Frank Schreiner
 
 You are more than welcome to contribute to MooseX-App. Please have a look
 at the L<https://github.com/maros/MooseX-App/issues?q=is%3Aissue+is%3Aopen+label%3AWishlist>
@@ -682,7 +688,7 @@ list of open wishlist issues for ideas.
 
 =head1 COPYRIGHT
 
-MooseX::App is Copyright (c) 2012-17 Maroš Kollár.
+MooseX::App is Copyright (c) 2012-21 Maroš Kollár.
 
 This library is free software and may be distributed under the same terms as
 perl itself. The full text of the licence can be found in the LICENCE file
